@@ -1,5 +1,6 @@
 "rntransform" <-
-function(var) {
+function(formula,data,family=gaussian) {
+	var <- ztransform(formula,data,family)
 	out <- rank(var) - 0.5
 	out[is.na(var)] <- NA
 	mP <- .5/max(out,na.rm=T)
@@ -7,3 +8,5 @@ function(var) {
 	out <- qnorm(out)
 	out
 }
+
+
